@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2009-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2009-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -109,7 +109,7 @@ class Horde_Rpc_ActiveSync extends Horde_Rpc
                         throw new Horde_Exception('Unknown Error');
                     }
                 } catch (Horde_Exception_AuthenticationFailure $e) {
-                    $this->_sendAuthenticationFailedHeaders();
+                    $this->_sendAuthenticationFailedHeaders($e);
                     exit;
                 } catch (Horde_Exception $e) {
                     $this->_handleError($e);
@@ -123,7 +123,7 @@ class Horde_Rpc_ActiveSync extends Horde_Rpc
                     throw new Horde_Exception('Unknown Error');
                 }
             } catch (Horde_Exception_AuthenticationFailure $e) {
-                $this->_sendAuthenticationFailedHeaders();
+                $this->_sendAuthenticationFailedHeaders($e);
                 exit;
             } catch (Horde_Exception $e) {
                 $this->_handleError($e);
@@ -142,25 +142,28 @@ class Horde_Rpc_ActiveSync extends Horde_Rpc
             try {
                 $ret = $this->_server->handleRequest($this->_get['Cmd'], $this->_get['DeviceId']);
                 if ($ret === false) {
-                    throw new Horde_ActiveSync_Exception(sprintf(
+                    throw new Horde_Rpc_Exception(sprintf(
                         'Received FALSE while handling %s command.', $this->_get['Cmd']));
                 } elseif ($ret !== true) {
                     $this->_contentType = $ret;
                 }
             } catch (Horde_ActiveSync_Exception_InvalidRequest $e) {
                 $this->_logger->err(sprintf(
-                    'Returning HTTP 400 while handling %s command', $this->_get['Cmd']));
+                    'Returning HTTP 400 while handling %s command. Error is: %s',
+                    $this->_get['Cmd'], $e->getMessage()));
                $this->_handleError($e);
-               header('HTTP/1.1 400 Invalid Request ' . $e->getMessage());
+               header('HTTP/1.1 400 Invalid Request');
                exit;
             } catch (Horde_Exception_AuthenticationFailure $e) {
-                $this->_sendAuthenticationFailedHeaders();
+                $this->_sendAuthenticationFailedHeaders($e);
                 exit;
             } catch (Horde_Exception $e) {
                 $this->_logger->err(sprintf(
-                    'Returning HTTP 500 while handling %s command.', $this->_get['Cmd']));
+                    'Returning HTTP 500 while handling %s command. Error is: %s',
+                    $this->_get['Cmd'],
+                    $e->getMessage()));
                 $this->_handleError($e);
-                header('HTTP/1.1 500 ' . $e->getMessage());
+                header('HTTP/1.1 500');
                 exit;
             }
             break;
@@ -228,10 +231,21 @@ class Horde_Rpc_ActiveSync extends Horde_Rpc
 
     /**
      * Send 401 Unauthorized headers.
+     *
+     * @param Horde_Exception_AuthenticationFailure
      */
-    protected function _sendAuthenticationFailedHeaders()
+    protected function _sendAuthenticationFailedHeaders($e)
     {
-        header('HTTP/1.1 401 Unauthorized');
-        header('WWW-Authenticate: Basic realm="Horde ActiveSync"');
+        switch ($e->getCode()) {
+        case Horde_ActiveSync_Status::SYNC_NOT_ALLOWED:
+        case Horde_ActiveSync_Status::DEVICE_BLOCKED_FOR_USER:
+            $this->_logger->err('Sending 403');
+            header('HTTP/1.1 403 Forbidden');
+            break;
+        default:
+        $this->_logger->err('Sending 401');
+            header('HTTP/1.1 401 Unauthorized');
+            header('WWW-Authenticate: Basic realm="Horde ActiveSync"');
+        }
     }
 }
