@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2007-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2007-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -147,7 +147,7 @@ class Horde_Rpc_Jsonrpc extends Horde_Rpc
         }
         $data = Horde_Serialize::serialize($data, Horde_Serialize::JSON);
         try {
-            $result = $client->post($url, $data, $headers);
+            $result = $client->post((string)$url, $data, $headers);
         } catch (Horde_Http_Exception $e) {
             throw new Horde_Rpc_Exception($e->getMessage());
         }
@@ -166,7 +166,7 @@ class Horde_Rpc_Jsonrpc extends Horde_Rpc
                                         isset($response->error->error) ? $response->error->error : null);
                 */
             }
-            throw new Horde_Rpc_Exception($http->getResponseBody());
+            throw new Horde_Rpc_Exception($result->getBody());
         } elseif ($result->code != 200) {
             throw new Horde_Rpc_Exception('Request couldn\'t be answered. Returned errorcode: "' . $result->code);
         }
