@@ -3,7 +3,7 @@
  * The Horde_Rpc_xmlrpc class provides an XMLRPC implementation of the
  * Horde RPC system.
  *
- * Copyright 2002-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -101,9 +101,9 @@ class Horde_Rpc_Xmlrpc extends Horde_Rpc
             'User-Agent' => 'Horde RPC client',
             'Content-Type' => 'text/xml');
         try {
-            $result = $client->post($url, xmlrpc_encode_request($method, $params), $headers);
+            $result = $client->post((string)$url, xmlrpc_encode_request($method, $params), $headers);
         } catch (Horde_Http_Exception $e) {
-            throw new Horde_Rpc_Exception($result);
+            throw new Horde_Rpc_Exception($e);
         }
         if ($result->code != 200) {
             throw new Horde_Rpc_Exception('Request couldn\'t be answered. Returned errorcode: "' . $result->code);
